@@ -6,20 +6,29 @@
 import os
 import stat
 import unittest
-import tempfile
-try:
-    import mock
-except ImportError:
-    from unittest import mock
-from six.moves import configparser
+import shutil
+from unittest import mock
+import configparser
 
-from knack.config import CLIConfig, get_config_parser
+from knack.config import CLIConfig
+from .util import TEMP_FOLDER_NAME, new_temp_folder
+
+
+def clean_local_temp_folder():
+    local_temp_folders = os.path.join(os.getcwd(), TEMP_FOLDER_NAME)
+    if os.path.exists(local_temp_folders):
+        shutil.rmtree(local_temp_folders)
 
 
 class TestCLIConfig(unittest.TestCase):
 
     def setUp(self):
-        self.cli_config = CLIConfig(config_dir=tempfile.mkdtemp())
+        self.cli_config = CLIConfig(config_dir=new_temp_folder())
+        # In case the previous test is stopped and doesn't clean up
+        clean_local_temp_folder()
+
+    def tearDown(self):
+        clean_local_temp_folder()
 
     def test_has_option(self):
         section = 'MySection'
@@ -157,9 +166,67 @@ class TestCLIConfig(unittest.TestCase):
         with self.assertRaises(ValueError):
             self.cli_config.getboolean(section, option)
 
+    def test_items(self):
+        file_section = "MySection"
+        file_value = 'file_value'
+        env_value = 'env_value'
+
+        # Test file-only options are listed
+        file_only_option = 'file_only_option'
+        self.cli_config.set_value(file_section, file_only_option, file_value)
+        items_result = self.cli_config.items(file_section)
+        self.assertEqual(len(items_result), 1)
+        self.assertEqual(items_result[0]['name'], file_only_option)
+        self.assertEqual(items_result[0]['value'], file_value)
+        self.cli_config.remove_option(file_section, file_only_option)
+
+        # Test env-only options are listed
+        with mock.patch.dict('os.environ', {'CLI_MYSECTION_ENV_ONLY_OPTION': env_value}):
+            items_result = self.cli_config.items(file_section)
+            self.assertEqual(len(items_result), 1)
+            self.assertEqual(items_result[0]['name'], 'env_only_option')
+            self.assertEqual(items_result[0]['value'], env_value)
+
+        # Test file options are overridden by env options, for both single-word and multi-word options
+        test_options = [
+            # file_option, file_value, env_name, env_value
+            # Test single-word option
+            ('optionsingle', 'file_value_single', 'CLI_MYSECTION_OPTIONSINGLE', 'env_value_single'),
+            # Test multi-word option
+            ('option_multiple', 'file_value_multiple', 'CLI_MYSECTION_OPTION_MULTIPLE', 'env_value_multiple')
+        ]
+        for file_option, file_value, env_name, env_value in test_options:
+            self.cli_config.set_value(file_section, file_option, file_value)
+            items_result = self.cli_config.items(file_section)
+            self.assertEqual(len(items_result), 1)
+            self.assertEqual(items_result[0]['value'], file_value)
+
+            with mock.patch.dict('os.environ', {env_name: env_value}):
+                items_result = self.cli_config.items(file_section)
+                self.assertEqual(len(items_result), 1)
+                self.assertEqual(items_result[0]['value'], env_value)
+
+            self.cli_config.remove_option(file_section, file_option)
+
+        # Test Invalid_Env_Var is not accepted on Linux
+        # Windows' env var is case-insensitive, so skip
+        import platform
+        if platform.system() != 'Windows':
+            # Not shown
+            with mock.patch.dict('os.environ', {'CLI_MYSECTION_Test_Option': env_value}):
+                items_result = self.cli_config.items(file_section)
+                self.assertEqual(len(items_result), 0)
+
+            # No overriding
+            self.cli_config.set_value(file_section, 'test_option', file_value)
+            with mock.patch.dict('os.environ', {'CLI_MYSECTION_Test_Option': env_value}):
+                items_result = self.cli_config.items(file_section)
+                self.assertEqual(len(items_result), 1)
+                self.assertEqual(items_result[0]['value'], file_value)
+
     def test_set_config_value(self):
         self.cli_config.set_value('test_section', 'test_option', 'a_value')
-        config = get_config_parser()
+        config = configparser.ConfigParser()
         config.read(self.cli_config.config_path)
         self.assertEqual(config.get('test_section', 'test_option'), 'a_value')
 
@@ -186,13 +253,15 @@ class TestCLIConfig(unittest.TestCase):
         file_mode = os.stat(self.cli_config.config_path).st_mode
         self.assertTrue(bool(file_mode & stat.S_IRUSR))
         self.assertTrue(bool(file_mode & stat.S_IWUSR))
-        self.assertFalse(bool(file_mode & stat.S_IXUSR))
-        self.assertFalse(bool(file_mode & stat.S_IRGRP))
-        self.assertFalse(bool(file_mode & stat.S_IWGRP))
-        self.assertFalse(bool(file_mode & stat.S_IXGRP))
-        self.assertFalse(bool(file_mode & stat.S_IROTH))
-        self.assertFalse(bool(file_mode & stat.S_IWOTH))
-        self.assertFalse(bool(file_mode & stat.S_IXOTH))
+        # only S_IRUSR and S_IWUSR are supported on Windows: https://docs.python.org/3.8/library/os.html#os.chmod
+        if os.name != 'nt':
+            self.assertFalse(bool(file_mode & stat.S_IXUSR))
+            self.assertFalse(bool(file_mode & stat.S_IRGRP))
+            self.assertFalse(bool(file_mode & stat.S_IWGRP))
+            self.assertFalse(bool(file_mode & stat.S_IXGRP))
+            self.assertFalse(bool(file_mode & stat.S_IROTH))
+            self.assertFalse(bool(file_mode & stat.S_IWOTH))
+            self.assertFalse(bool(file_mode & stat.S_IXOTH))
 
     def test_has_option_local(self):
         section = 'MySection'
